@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::errno;
 use strict;
 use Acme::MetaSyntactic::MultiList;
 our @ISA     = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 use Errno ();
 
@@ -38,6 +38,10 @@ Philippe Bruhat (BooK)
 
 =item *
 
+2012-07-13 - v1.001
+
+Added a LICENSE section, to please CPANTS.
+
 2012-06-21 - v1.000
 
 Published as part of the Booking.com Hackathon.
@@ -49,5 +53,10 @@ Published as part of the Booking.com Hackathon.
 L<Errno>,
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
 
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
 =cut
 
